@@ -86,8 +86,8 @@ set_unions = Set.unions
 ---------------------------------------------------------------------
 -- GHC 7.2 and above (using unordered-containers API)
 
-(!) mp k = Map.lookupDefault (error "Could not find element") k mp
-map_findWithDefault = Map.lookupDefault
+(!) mp k = map_findWithDefault (error "Could not find element") k mp
+map_findWithDefault d k mp = fromMaybe d $ Map.lookup k mp -- in 0.2.3.0 lookupDefault is strict in the default :(
 map_fromAscList = Map.fromList
 map_keysSet = Set.fromList . Map.keys
 map_member x xs = isJust $ Map.lookup x xs
@@ -322,6 +322,15 @@ descendBiData oracle op x = case oracle x of
     Follow -> gmapT (descendBiData oracle op) x
     Miss -> x
 
+descendDataM :: (Data on, Monad m) => (forall a . Typeable a => a -> Answer on) -> (on -> m on) -> on -> m on
+descendDataM oracle op = gmapM (descendBiDataM oracle op)
+
+descendBiDataM :: (Data on, Data with, Monad m) => (forall a . Typeable a => a -> Answer with) -> (with -> m with) -> on -> m on
+descendBiDataM oracle op x = case oracle x of
+    Hit y -> unsafeCoerce $ op y
+    Follow -> gmapM (descendBiDataM oracle op) x
+    Miss -> return x
+
 
 ---------------------------------------------------------------------
 -- FUSION
